from typing import Any, Dict, List
from .requester import Requester


class MountainProject(object):
    def __init__(self, access_key: str) -> None:
        self.__requester = Requester(access_key)

    def get_user(self, email: str = None, user_id: str = None) -> Dict[str, Any]:
        arg_error = "requires exactly one of email or user_id"
        assert not (email is None and user_id is None), arg_error
        assert not (email is not None and user_id is not None), arg_error

        params = {"email": email, "userId": user_id}
        return self.__requester.get("/get-user", params=params)

    def get_ticks(self, email: str = None, user_id: str = None) -> Dict[str, Any]:
        arg_error = "requires exactly one of email or user_id"
        assert not (email is None and user_id is None), arg_error
        assert not (email is not None and user_id is not None), arg_error

        params = {"email": email, "userId": user_id}
        return self.__requester.get("/get-ticks", params=params)

    def get_todos(self, email: str = None, user_id: str = None) -> Dict[str, Any]:
        arg_error = "requires exactly one of email or user_id"
        assert not (email is None and user_id is None), arg_error
        assert not (email is not None and user_id is not None), arg_error

        params = {"email": email, "userId": user_id}
        return self.__requester.get("/get-to-dos", params=params)

    def get_routes(self, route_ids: List[str]) -> Dict[str, Any]:
        cs_route_ids = ",".join(route_ids)
        params = {"routeIds": cs_route_ids}
        return self.__requester.get("/get-routes", params=params)

    def get_routes_for_lat_lon(
        self,
        lat: float,
        lon: float,
        max_distance: float = None,
        max_results: int = None,
        min_difficulty: str = None,
        max_difficulty: str = None,
    ):
        params = {
            "lat": lat,
            "lon": lon,
            "maxDistance": max_distance,
            "maxResults": max_results,
            "minDiff": min_difficulty,
            "maxDiff": max_difficulty,
        }
        return self.__requester.get("/get-routes-for-lat-lon", params=params)



from typing import Any

import requests


class Requester(object):
    def __init__(self, access_key: str) -> None:
        self.__domain = "https://www.mountainproject.com/data"
        self.__base_params = {"key": access_key}

    def get(self, path: str, params: dict = {}) -> Any:
        url = f"{self.__domain}{path}"
        request_params = {**self.__base_params, **params}
        response = requests.get(url, params=request_params)
        if response.status_code == 200:
            return response.json()
        else:
            raise RequestException(response.status_code, response.text)


class RequestException(Exception):
    def __init__(self, status_code: int, data: str):
        self.__status_code = status_code
        self.__data = data

    def __str__(self):
        return f"{self.__status_code}: {self.__data}"



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mountain_project']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.22.0,<3.0.0']

setup_kwargs = {
    'name': 'mountain-project',
    'version': '0.1.0',
    'description': 'Python MountainProject API Client',
    'long_description': '[![CircleCI](https://circleci.com/gh/Ben-Hu/mountain_project.svg?style=svg)](https://circleci.com/gh/Ben-Hu/mountain_project) [![codecov](https://codecov.io/gh/Ben-Hu/mountain_project/branch/master/graph/badge.svg)](https://codecov.io/gh/Ben-Hu/mountain_project) [![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/Ben-Hu/mountain_project.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Ben-Hu/mountain_project/context:python) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) ![License](https://img.shields.io/github/license/Ben-Hu/mountain_project) ![Tag](https://img.shields.io/github/v/tag/Ben-Hu/mountain_project)\n\n# MountainProject\nPython MountainProject API Client\n\n## Getting Started\n- Sign up for MountainProject @ `https://www.mountainproject.com`\n- Get your access key for the MountainProject data API @ `https://www.mountainproject.com/data`\n\n```python\nfrom mountain_project import MountainProject\n\nm = MountainProject("access_key")\nuser = m.get_user("test@test.com")\nticks = m.get_ticks("test@test.com")\ntodos = m.get_todos("test@test.com")\nroutes_by_id = m.get_routes(["106034519", "111519266", "106028737"])\nroutes_by_location = m.get_routes_for_lat_lon(49.6867, -123.1350)\n```',
    'author': 'Ben-Hu',
    'author_email': 'benjqh@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
